Enum Chside
#[repr(u8)]pub enum Chside {
Left = 0,
Right = 1,
}Variants
Left = 0
Channel left has to be transmitted or has been received
Right = 1
Channel right has to be transmitted or has been received
Implementations